@@ -36,57 +36,61 @@
 
 import locale
 
+
 # JSON
 
 
 class JSON_Object(object):
+    """
+    Converts Python object into JSON compatible data
+    structures. Types like lists, tuples and dictionary are converted
+    directly. If none of these types matches the method tries to convert
+    the attributes of the object and generate a dict to represent it.
+    """
 
-	'''Converts Python object into JSON compatible data
-	structures. Types like lists, tuples and dictionary are converted
-	directly. If none of these types matches the method tries to convert
-	the attributes of the object and generate a dict to represent it.'''
+    def _json_list(self, obj):
+        result = []
+        for item in obj:
+            if isinstance(item, JSON_Object):
+                result.append(item.json())
+            else:
+                result.append(item)
+        return result
 
-	def _json_list(self, obj):
-		result = []
-		for item in obj:
-			if isinstance(item, JSON_Object):
-				result.append(item.json())
-			else:
-				result.append(item)
-		return result
+    def _json_dict(self, obj):
+        result = {}
+        for key, value in obj.items():
+            if isinstance(value, JSON_Object):
+                result[key] = value.json()
+            else:
+                result[key] = value
+        return result
 
-	def _json_dict(self, obj):
-		result = {}
-		for key, value in obj.items():
-			if isinstance(value, JSON_Object):
-				result[key] = value.json()
-			else:
-				result[key] = value
-		return result
-
-	def json(self):
-		if isinstance(self, (list, tuple)):
-			return self._json_list(self)
-		elif isinstance(self, dict):
-			return self._json_dict(self)
-		return self._json_dict(self.__dict__)
+    def json(self):
+        if isinstance(self, (list, tuple)):
+            return self._json_list(self)
+        elif isinstance(self, dict):
+            return self._json_dict(self)
+        return self._json_dict(self.__dict__)
 
 
 class JSON_List(list, JSON_Object):
-	pass
+    pass
 
 
 class JSON_Dict(dict, JSON_Object):
-	pass
+    pass
 
 # locales
 
 
 def locale_get():
-	'''Get locale name for messages. If no specific locale is set for
-	process the default setting is returned.'''
-	lang, encoding = locale.getlocale(locale.LC_MESSAGES)
-	if not lang:
-		lang, encoding = locale.getdefaultlocale(locale.LC_MESSAGES)
+    """
+    Get locale name for messages. If no specific locale is set for
+    process the default setting is returned.
+    """
+    lang, encoding = locale.getlocale(locale.LC_MESSAGES)
+    if not lang:
+        lang, encoding = locale.getdefaultlocale(locale.LC_MESSAGES)
 
-	return lang
+    return lang
